import { NodeStream, TwitchGame, TwitchResponse, TwitchUser } from './@types/RequestTypes';
export default class TwitchClient {
    clientID: string;
    constructor(clientID?: string);
    endpoint: string;
    /**
     * Request Twitch Data
     * @param {string} schema The GQL Schema
     * @param {object} variables The variables needed for the request
     * @returns {TwitchResponse}
     */
    request(schema: string, variables: object): Promise<TwitchResponse>;
    /**
     * Fetches a twitch user and returns their info and streaming status, if there is no user it will return null.
     * @param {string} userID The Twitch ID of the user you want to fetch.
     * @returns {TwitchUser | null}
     */
    fetchUserByID(userID: string): Promise<TwitchUser | null>;
    /**
     * Fetches a twitch user by their username and returns their info and streaming status, if there is no user it will return null.
     * @param {string} username The Twitch ID of the user you want to fetch.
     * @returns {TwitchUser | null}
     */
    fetchUserByName(username: string): Promise<TwitchUser | null>;
    /**
     * Fetches a twitch game and returns its info, null if not found.
     * @param {string} name The name of the game. Eg Rocket League.
     * @returns {TwitchGame | null}
     */
    fetchGameByName(name: string): Promise<TwitchGame>;
    /**
     * Fetches the trending Twitch Feed, null or undefined if not found
     * @param {string} limit The amount of posts to fetch.
     * @returns {NodeStream[] | null | undefined}
     */
    fetchTrendingFeed(limit: number): Promise<NodeStream[] | null | undefined>;
}
